@@ -1,6 +1,6 @@
 /*
    This file is part of GNU Anubis 
-   Copyright (C) 2004-2014 The Anubis Team.
+   Copyright (C) 2004-2020 The Anubis Team.
 
    GNU Anubis is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -353,7 +353,7 @@ main (int argc, char **argv)
 
   dbtext_init ();
 # ifdef HAVE_LIBGDBM
-  gdbm_db_init ();
+  db_gdbm_init ();
 # endif
 # ifdef WITH_MYSQL
   mysql_db_init ();
