@@ -1,7 +1,7 @@
 /*
    anubisusr.c
    
-   Copyright (C) 2004-2014 The Anubis Team.
+   Copyright (C) 2004-2020 The Anubis Team.
 
    GNU Anubis is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -879,7 +879,8 @@ synch (void)
     }
 
   stream_create (&iostream);
-  stream_set_io (iostream, (void *) fd, NULL, NULL, NULL, NULL, NULL);
+  stream_set_io (iostream, (void *) (ptrdiff_t) fd, NULL, NULL, NULL, NULL,
+		 NULL);
 
   repl = smtp_reply_new ();
   smtp_get_reply (repl);
@@ -890,7 +891,6 @@ synch (void)
       smtp_reply_free (repl);
       return 1;
     }
-  smtp_reply_free (repl);
 
   smtp_ehlo (1);
 
@@ -909,6 +909,7 @@ synch (void)
   if (!smtp_reply_has_capa (smtp_capa, "XDATABASE", NULL))
     {
       error (_("Remote party does not reveal XDATABASE capability"));
+      smtp_reply_free (repl);
       smtp_quit ();
       return 1;
     }
