@@ -2,7 +2,7 @@
    headers.h
 
    This file is part of GNU Anubis.
-   Copyright (C) 2001-2014 The Anubis Team.
+   Copyright (C) 2001-2020 The Anubis Team.
 
    GNU Anubis is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -524,9 +524,8 @@ void gpg_section_init (void);
 void init_guile (void);
 void guile_debug (int);
 void guile_section_init (void);
-void guile_init_anubis_error_port (void);
+void guile_init_anubis_log_port (void);
 SCM guile_make_anubis_error_port (int err);
-void guile_init_anubis_info_port (void);
 SCM guile_make_anubis_info_port (void);
 #endif /* WITH_GUILE */
 
@@ -604,7 +603,7 @@ void anubis_db_free_record (ANUBIS_USER * rec);
 void dbtext_init (void);
 
 /* gdbm.c */
-void gdbm_db_init (void);
+void db_gdbm_init (void);
 
 /* mysql.c */
 void mysql_db_init (void);
